@@ -1,3 +1,4 @@
+import json
 from collections import defaultdict
 from datetime import datetime
 from http import HTTPStatus
@@ -21,6 +22,8 @@ from pyctuator.logging.pyctuator_logging import LoggersData, LoggerLevels
 from pyctuator.metrics.metrics_provider import Metric, MetricNames
 from pyctuator.threads.thread_dump_provider import ThreadDump
 
+from dataclasses import asdict
+
 
 class FastApiLoggerItem(BaseModel):
     configuredLevel: Optional[str]
@@ -35,7 +38,7 @@ class FastApiPyctuator(PyctuatorRouter):
             app: FastAPI,
             pyctuator_impl: PyctuatorImpl,
             include_in_openapi_schema: bool = False,
-            customizer: Callable[[APIRouter], None] = None
+            customizer: Optional[Callable[[APIRouter], None]] = None
     ) -> None:
         super().__init__(app, pyctuator_impl)
         router = APIRouter()
@@ -43,8 +46,8 @@ class FastApiPyctuator(PyctuatorRouter):
             customizer(router)
 
         @router.get("/", include_in_schema=include_in_openapi_schema, tags=["pyctuator"])
-        def get_endpoints() -> EndpointsData:
-            return self.get_endpoints_data()
+        def get_endpoints() -> object:
+            return {"_links": self.get_endpoints_links()}
 
         @router.options("/env", include_in_schema=include_in_openapi_schema)
         @router.options("/info", include_in_schema=include_in_openapi_schema)
@@ -74,7 +77,7 @@ class FastApiPyctuator(PyctuatorRouter):
             return pyctuator_impl.get_app_info()
 
         @router.get("/health", include_in_schema=include_in_openapi_schema, tags=["pyctuator"])
-        def get_health(response: Response) -> HealthSummary:
+        def get_health(response: Response) -> object:
             health = pyctuator_impl.get_health()
             response.status_code = health.http_status()
             return health
